summaryrefslogtreecommitdiffstats
path: root/dcop/dcopidlng
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
commit560378aaca1784ba19806a0414a32b20c744de39 (patch)
treece0dfd7c3febf2a1adc7603d1019a8be2083c415 /dcop/dcopidlng
parentd4d5af1cdbd3cc65d095e0afc5b1f4260091cf5d (diff)
downloadtdelibs-560378aaca1784ba19806a0414a32b20c744de39.tar.gz
tdelibs-560378aaca1784ba19806a0414a32b20c744de39.zip
Automated conversion for enhanced compatibility with TQt for Qt4 3.4.0 TP1
NOTE: This will not compile with Qt4 (yet), however it does compile with Qt3 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1211081 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'dcop/dcopidlng')
-rw-r--r--dcop/dcopidlng/kalyptus28
-rw-r--r--dcop/dcopidlng/kdocAstUtil.pm38
-rw-r--r--dcop/dcopidlng/kdocUtil.pm6
3 files changed, 36 insertions, 36 deletions
diff --git a/dcop/dcopidlng/kalyptus b/dcop/dcopidlng/kalyptus
index 9a3709fc0..b0f0e1871 100644
--- a/dcop/dcopidlng/kalyptus
+++ b/dcop/dcopidlng/kalyptus
@@ -67,14 +67,14 @@ $exe = basename $0;
@inputqueue = ();
@codeqobject = split "\n", <<CODE;
public:
- virtual QMetaObject *metaObject() const;
+ virtual QMetaObject *tqmetaObject() const;
virtual const char *className() const;
virtual void* qt_cast( const char* );
virtual bool qt_invoke( int, QUObject* );
virtual bool qt_emit( int, QUObject* );
virtual bool qt_property( int, int, QVariant* );
static QMetaObject* staticMetaObject();
- QObject* qObject();
+ TQObject* qObject();
static QString tr( const char *, const char * = 0 );
static QString trUtf8( const char *, const char * = 0 );
private:
@@ -116,7 +116,7 @@ $allowed_k_dcop_accesors_re = join("|", @allowed_k_dcop_accesors);
Q_WS_MAC => 'undef',
Q_OBJECT => <<'CODE',
public:
- virtual QMetaObject *metaObject() const;
+ virtual QMetaObject *tqmetaObject() const;
virtual const char *className() const;
virtual bool qt_invoke( int, QUObject* );
virtual bool qt_emit( int, QUObject* );
@@ -419,7 +419,7 @@ LOOP:
}
next if ( $p =~ /^\s*$/s ); # blank lines
-# || $p =~ /^\s*Q_OBJECT/ # QObject macro
+# || $p =~ /^\s*Q_OBJECT/ # TQObject macro
# );
#
@@ -514,7 +514,7 @@ sub readCxxCodeBlock
return $lastLine if ( $open || $close) && $count == 0;
}
- # find opening brace
+ # tqfind opening brace
if ( $count == 0 ) {
while( $count == 0 ) {
$l = readCxxLine();
@@ -529,7 +529,7 @@ sub readCxxCodeBlock
$count -= kdocUtil::countReg( $l, "}" );
}
- # find associated closing brace
+ # tqfind associated closing brace
while ( $count > 0 ) {
$l = readCxxLine();
croak "Confused by unmatched braces" if !defined $l;
@@ -1096,8 +1096,8 @@ sub newClass
my $access = "private";
$access = "public" if $cNodeType ne "class";
- # try to find an exisiting node, or create a new one
- # We need to make the fully-qualified-name otherwise findRef will look
+ # try to tqfind an exisiting node, or create a new one
+ # We need to make the fully-qualified-name otherwise tqfindRef will look
# for that classname in the global namespace
# testcase: class Foo; namespace Bar { class Foo { ... } }
my @parents;
@@ -1105,7 +1105,7 @@ sub newClass
push @parents, $name;
my $fullyQualifiedName = join "::", @parents;
print "looking for $fullyQualifiedName\n" if($debug);
- my $oldnode = kdocAstUtil::findRef( $cNode, $fullyQualifiedName );
+ my $oldnode = kdocAstUtil::tqfindRef( $cNode, $fullyQualifiedName );
my $node = defined $oldnode ? $oldnode : Ast::New( $name );
if ( $endTag ne "{" ) {
@@ -1344,15 +1344,15 @@ sub newMethod
# ALWAYS IGNORE...
return undef;
- my $node = kdocAstUtil::findRef( $cNode, $class );
+ my $node = kdocAstUtil::tqfindRef( $cNode, $class );
if ( !defined $node ) {
- # if we couldn't find the name, try again with
+ # if we couldn't tqfind the name, try again with
# all template parameters stripped off:
my $strippedClass = $class;
$strippedClass =~ s/<[^<>]*>//g;
- $node = kdocAstUtil::findRef( $cNode, $strippedClass );
+ $node = kdocAstUtil::tqfindRef( $cNode, $strippedClass );
# if still not found: give up
if ( !defined $node ) {
@@ -1370,7 +1370,7 @@ sub newMethod
$class = $globalSpaceClassName; # FIXME - sanitize the naming system?
$isGlobalSpace = 1;
- my $opsNode = kdocAstUtil::findRef( $cNode, $class );
+ my $opsNode = kdocAstUtil::tqfindRef( $cNode, $class );
if (!$opsNode) {
# manually create a "GlobalSpace" class
$opsNode = Ast::New( $class );
@@ -1468,7 +1468,7 @@ sub newMethod
* 1 for enums
Adds a property "ParamList" to the method node.
- This property contains a list of nodes, one for each parameter.
+ This property tqcontains a list of nodes, one for each parameter.
Each parameter node has the following properties:
* ArgType the type of the argument, e.g. const QString&
diff --git a/dcop/dcopidlng/kdocUtil.pm b/dcop/dcopidlng/kdocUtil.pm
index 629147ac3..e83359724 100644
--- a/dcop/dcopidlng/kdocUtil.pm
+++ b/dcop/dcopidlng/kdocUtil.pm
@@ -30,7 +30,7 @@ sub countReg
return $count;
}
-=head2 findCommonPrefix
+=head2 tqfindCommonPrefix
Parameters: string, string
@@ -39,7 +39,7 @@ sub countReg
=cut
-sub findCommonPrefix
+sub tqfindCommonPrefix
{
my @s1 = split( "/", $_[0] );
my @s2 = split( "/", $_[1] );
@@ -72,7 +72,7 @@ sub makeRelativePath
$from .= '/' unless $from =~ m#/$#;
$to .= '/' unless $to =~ m#/$#;
- my $pfx = findCommonPrefix( $from, $to );
+ my $pfx = tqfindCommonPrefix( $from, $to );
if ( $pfx ne "" ) {
$from =~ s/^$pfx//g;
diff --git a/dcop/dcopidlng/kdocAstUtil.pm b/dcop/dcopidlng/kdocAstUtil.pm
index ec67ace5f..27f65dd21 100644
--- a/dcop/dcopidlng/kdocAstUtil.pm
+++ b/dcop/dcopidlng/kdocAstUtil.pm
@@ -17,13 +17,13 @@ use strict;
use vars qw/ $depth $refcalls $refiters @noreflist %noref /;
sub BEGIN {
# statistics for findRef
$depth = 0;
$refcalls = 0;
$refiters = 0;
# findRef will ignore these words
@noreflist = qw( const int char long double template
unsigned signed float void bool true false uint
@@ -35,22 +35,22 @@ sub BEGIN {
}
-=head2 findRef
+=head2 tqfindRef
Parameters: root, ident, report-on-fail
Returns: node, or undef
Given a root node and a fully qualified identifier (:: separated),
- this function will try to find a child of the root node that matches
+ this function will try to tqfind a child of the root node that matches
the identifier.
=cut
-sub findRef
+sub tqfindRef
{
my( $root, $name, $r ) = @_;
- confess "findRef: no name" if !defined $name || $name eq "";
+ confess "tqfindRef: no name" if !defined $name || $name eq "";
$name =~ s/\s+//g;
return undef if exists $noref{ $name };
@@ -65,7 +65,7 @@ sub findRef
# Upward search for the first token
return undef if !defined $iter;
- while ( !defined findIn( $root, $iter ) ) {
+ while ( !defined tqfindIn( $root, $iter ) ) {
return undef if !defined $root->{Parent};
$root = $root->{Parent};
}
@@ -77,8 +77,8 @@ sub findRef
confess "iter in $name is undefined\n" if !defined $iter;
next if $iter =~ /^\s*$/;
- unless ( defined findIn( $root, $iter ) ) {
- confess "findRef: failed on '$name' at '$iter'\n"
+ unless ( defined tqfindIn( $root, $iter ) ) {
+ confess "tqfindRef: failed on '$name' at '$iter'\n"
if defined $r;
return undef;
}
@@ -90,13 +90,13 @@ sub findRef
return $root;
}
-=head2 findIn
+=head2 tqfindIn
node, name: search for a child
=cut
-sub findIn
+sub tqfindIn
{
return undef unless defined $_[0]->{KidHash};
@@ -147,7 +147,7 @@ ANITER:
next ANITER;
}
- my $ref = kdocAstUtil::findRef( $rnode,
+ my $ref = kdocAstUtil::tqfindRef( $rnode,
$in->{astNodeName} );
if( !defined $ref ) {
@@ -302,16 +302,16 @@ sub allMembers
}
}
-=head2 findOverride
+=head2 tqfindOverride
Parameters: root, node, name
Looks for nodes of the same name as the parameter, in its parent
- and the parent's ancestors. It returns a node if it finds one.
+ and the parent's ancestors. It returns a node if it tqfinds one.
=cut
-sub findOverride
+sub tqfindOverride
{
my ( $root, $node, $name ) = @_;
return undef if !exists $node->{InList};
@@ -325,7 +325,7 @@ sub findOverride
return $n if defined $ref && $ref->{NodeType} eq "method";
if ( exists $n->{InList} ) {
- $ref = findOverride( $root, $n, $name );
+ $ref = tqfindOverride( $root, $n, $name );
return $ref if defined $ref;
}
}
@@ -464,14 +464,14 @@ sub testRef {
my $rootNode = $_[ 0 ];
- my $term = new Term::ReadLine 'Testing findRef';
+ my $term = new Term::ReadLine 'Testing tqfindRef';
my $OUT = $term->OUT || *STDOUT{IO};
my $prompt = "Identifier: ";
while( defined ($_ = $term->readline($prompt)) ) {
- my $node = kdocAstUtil::findRef( $rootNode, $_ );
+ my $node = kdocAstUtil::tqfindRef( $rootNode, $_ );
if( defined $node ) {
print $OUT "Reference: '", $node->{astNodeName},
@@ -487,7 +487,7 @@ sub testRef {
sub printDebugStats
{
- print "findRef: ", $refcalls, " calls, ",
+ print "tqfindRef: ", $refcalls, " calls, ",
$refiters, " iterations.\n";
}
@@ -17,13 +17,13 @@ use strict;
use vars qw/ $depth $refcalls $refiters @noreflist %noref /;
sub BEGIN {
-# statistics for findRef
+# statistics for tqfindRef
$depth = 0;
$refcalls = 0;
@@ -17,13 +17,13 @@ use strict;
$refcalls = 0;
$refiters = 0;
-# findRef will ignore these words
+# tqfindRef will ignore these words
unsigned signed float void bool true false uint